summaryrefslogtreecommitdiff
path: root/ofproto/ofproto-provider.h
diff options
context:
space:
mode:
authorBen Pfaff <blp@ovn.org>2020-06-17 14:16:08 -0700
committerBen Pfaff <blp@ovn.org>2020-10-21 11:28:24 -0700
commit91fc374a9c5a2a4d9520aaa3588a7a18338a476e (patch)
tree36e097d0f7b655e90179c04e21eb7fe4c400889b /ofproto/ofproto-provider.h
parentf51cf36d86e4a51630dc2781034149c13a634d67 (diff)
downloadopenvswitch-91fc374a9c5a2a4d9520aaa3588a7a18338a476e.tar.gz
Eliminate use of term "slave" in bond, LACP, and bundle contexts.
The new term is "member". Most of these changes should not change user-visible behavior. One place where they do is in "ovs-ofctl dump-flows", which will now output "members:..." inside "bundle" actions instead of "slaves:...". I don't expect this to cause real problems in most systems. The old syntax is still supported on input for backward compatibility. Signed-off-by: Ben Pfaff <blp@ovn.org> Acked-by: Alin Gabriel Serdean <aserdean@cloudbasesolutions.com>
Diffstat (limited to 'ofproto/ofproto-provider.h')
-rw-r--r--ofproto/ofproto-provider.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/ofproto/ofproto-provider.h b/ofproto/ofproto-provider.h
index afecb24cb..9ad2b71d2 100644
--- a/ofproto/ofproto-provider.h
+++ b/ofproto/ofproto-provider.h
@@ -1225,7 +1225,7 @@ struct ofproto_class {
* not support LACP.
*/
int (*port_get_lacp_stats)(const struct ofport *port,
- struct lacp_slave_stats *stats);
+ struct lacp_member_stats *stats);
/* ## ----------------------- ## */
/* ## OpenFlow Rule Functions ## */
@@ -1707,11 +1707,11 @@ struct ofproto_class {
/* If 's' is nonnull, this function registers a "bundle" associated with
* client data pointer 'aux' in 'ofproto'. A bundle is the same concept as
* a Port in OVSDB, that is, it consists of one or more "slave" devices
* (Interfaces, in OVSDB) along with VLAN and LACP configuration and, if
* there is more than one slave, a bonding configuration. If 'aux' is
* already registered then this function updates its configuration to 's'.
* Otherwise, this function registers a new bundle.
*
* If 's' is NULL, this function unregisters the bundle registered on
* 'ofproto' associated with client data pointer 'aux'. If no such bundle
@@ -1707,11 +1707,11 @@ struct ofproto_class {
/* If 's' is nonnull, this function registers a "bundle" associated with
* client data pointer 'aux' in 'ofproto'. A bundle is the same concept as
- * a Port in OVSDB, that is, it consists of one or more "slave" devices
- * (Interfaces, in OVSDB) along with VLAN and LACP configuration and, if
- * there is more than one slave, a bonding configuration. If 'aux' is
- * already registered then this function updates its configuration to 's'.
- * Otherwise, this function registers a new bundle.
+ * a Port in OVSDB, that is, it consists of one or more "member"
+ * devices (Interfaces, in OVSDB) along with VLAN and LACP configuration
+ * and, if there is more than one member, a bonding configuration. If 'aux'
+ * is already registered then this function updates its configuration to
+ * 's'. Otherwise, this function registers a new bundle.
*
* If 's' is NULL, this function unregisters the bundle registered on